@@ -87,6 +87,8 @@ ExtFunc void auth_send(struct arglist *, char *);
 ExtFunc char * auth_gets(struct arglist *, char * , size_t);
 ExtFunc int ping_host(struct in_addr);
 
+ExtFunc unsigned short *getpts(char *, int *);
+
 /* 
  * Management of the arglists --should not be used directly by
  * the plugins
@@ -426,6 +428,7 @@ ExtFunc int bpf_server();
 ExtFunc int bpf_open_live(char*, char*);
 ExtFunc u_char* bpf_next(int, int *);
 ExtFunc void bpf_close(int);
+ExtFunc int bpf_datalink(int);
 
 void initsetproctitle(int argc, char *argv[], char *envp[]);
 #ifndef HAVE_SETPROCTITLE
